from fastapi import APIRouter, Request

from openaoe.backend.model.claude import ClaudeChatBody
from openaoe.backend.service.service_claude import claude_chat_stream_svc


router = APIRouter()


@router.post("/v1/text/chat-stream", tags=["claude"])
async def claude_chat_stream(request: Request, body: ClaudeChatBody):
    ret = claude_chat_stream_svc(request, body)
    return ret



import logging


def log(name):
    logger = logging.getLogger(name)
    logger.setLevel(logging.INFO)
    formatter = logging.Formatter(
        "%(levelname)s:     %(asctime)s - %(module)s-%(funcName)s-line:%(lineno)d - %(message)s"
    )
    ch = logging.StreamHandler()
    ch.setFormatter(formatter)
    logger.addHandler(ch)
    return logger


logger = log("util")



from fastapi import APIRouter, Request

from openaoe.backend.model.google import GooglePalmChatBody
from openaoe.backend.service.service_google import palm_chat_svc


router = APIRouter()


@router.post("/v1/palm/chat", tags=["PaLM"])
async def palm_chat(body: GooglePalmChatBody):
    ret = palm_chat_svc(body)
    return ret



from fastapi import APIRouter, Request

from openaoe.backend.model.openai import OpenaiChatStreamBody
from openaoe.backend.service.service_openai import chat_completion_stream

router = APIRouter()


@router.post("/v1/text/chat-stream", tags=["OpenAI"])
async def openai_chat_stream(request: Request, req_dto: OpenaiChatStreamBody):
    """
    OpenAI ChatCompletion with Stream
    """
    ret = chat_completion_stream(request, req_dto)
    return ret





from pydantic import BaseModel
from typing import Optional, List


class Message(BaseModel):
    content: str
    author: Optional[str] = 0


class Prompt(BaseModel):
    messages: List[Message]


class GooglePalmChatBody(BaseModel):
    model: Optional[str] = "chat-bison-001"
    prompt: Prompt
    temperature: Optional[float] = 0.1
    candidate_count: Optional[int] = 1


class TextPrompt(BaseModel):
    text: str


class GoogleSafetySetting(BaseModel):
    category: Optional[str] = "HARM_CATEGORY_UNSPECIFIED"
    threshold: Optional[str] = "BLOCK_NONE"


class GooglePalmTextBody(BaseModel):
    model: Optional[str] = "text-bison-001"
    prompt: TextPrompt
    temperature: Optional[float] = 0.1
    candidate_count: Optional[int] = 1
    max_output_tokens: Optional[int] = 1024
    safety_settings: Optional[List[GoogleSafetySetting]] = []


class GoogleBardAskImgBody(BaseModel):
    img_url: str
    prompt: str
    bard_token: str




import json

import requests
from fastapi import Request

from openaoe.backend.config.biz_config import get_api_key, get_base_url
from openaoe.backend.config.constant import *
from openaoe.backend.model.aoe_response import AOEResponse
from openaoe.backend.model.google import GooglePalmChatBody
from openaoe.backend.util.log import log


logger = log(__name__)


def palm_chat_svc(req_dto: GooglePalmChatBody):
    api_key = get_api_key(VENDOR_GOOGLE)
    url = get_base_url(VENDOR_GOOGLE)
    url = f"{url}/google/v1beta2/models/{req_dto.model}:generateMessage?key={api_key}"
    messages = [
        {"content": msg.content, "author": msg.author}
        for msg in req_dto.prompt.messages or []
    ]
    body = {
        "prompt": {
            "messages": messages
        },
        "temperature": req_dto.temperature,
        "candidate_count": req_dto.candidate_count,
        "model": req_dto.model
    }
    try:
        response_json = requests.post(
            url=url,
            data=json.dumps(body)
        ).json()
        if response_json.get('error') is not None:
            err_msg = response_json.get('error').get("message")
            base = AOEResponse(
                msg="error",
                msgCode="-1",
                data=err_msg
            )
            return base

        # remove messages
        if response_json and response_json.get("messages"):
            response_json.pop("messages")
        base = AOEResponse(
            data=response_json
        )
    except Exception as e:
        logger.error(f"{e}")
        base = AOEResponse(
            msg="error",
            msgCode="-1",
            data=str(e)
        )
    return base



import json

import requests
from fastapi.encoders import jsonable_encoder
from sse_starlette.sse import EventSourceResponse

from openaoe.backend.config.biz_config import get_base_url
from openaoe.backend.config.constant import *
from openaoe.backend.model.internlm import InternlmChatCompletionBody
from openaoe.backend.model.aoe_response import AOEResponse
from openaoe.backend.util.log import log

logger = log(__name__)


def chat_completion_v1(request, req_dto: InternlmChatCompletionBody):
    messages = req_dto.messages
    msgs = []
    for msg in messages:
        if msg.sender_type == "bot":
            msg.sender_type = req_dto.role_meta.bot_name
        msg_item = {
            "role": msg.sender_type,
            "content": jsonable_encoder(msg.text),
        }
        msgs.append(msg_item)
    msg_item = {
        "role": "user",
        "content": req_dto.prompt
    }
    msgs.append(msg_item)
    # restful api
    url = get_base_url(VENDOR_INTERNLM) + "/v1/chat/completions"
    headers = {
        'accept': 'application/json',
        'Content-Type': 'application/json'
    }
    data = {
        "model": req_dto.model,
        "messages": msgs,
        "temperature": req_dto.temperature,
        "top_p": req_dto.top_p,
        "n": req_dto.n,
        "max_tokens": req_dto.max_tokens,
        "stop": False,
        "stream": req_dto.stream,
        "presence_penalty": req_dto.presence_penalty,
        "frequency_penalty": req_dto.frequency_penalty,
        "user": "string",
        "repetition_penalty": 1,
        "session_id": -1,
        "ignore_eos": False
    }
    if req_dto.stream:
        return chat_completion_stream_v1(request, url, headers, data)
    else:
        res = requests.post(url, headers=headers, json=data)
        if res and res.status_code == 200:
            base = AOEResponse(
                data=res.json()
            )
            return base
        else:
            return AOEResponse(
                data="request failed"
            )


def chat_completion_stream_v1(request, url, headers, data):
    async def event_generator_json():
        while True:
            stop_flag = False
            response = ""
            if await request.is_disconnected():
                break
            try:
                res = requests.post(url, headers=headers, json=data)
                res_data = res.text.replace("data: ", "")
                json_strings = res_data.split("\n\n")
                # 解析 JSON 数据
                for chunk in json_strings:
                    try:
                        json_data = json.loads(chunk)
                        choice = json_data["choices"][0]
                        if choice['finish_reason']:
                            stop_flag = True
                        if 'content' not in choice['delta']:
                            continue
                        s = choice["delta"]["content"]
                        if s:
                            response += s
                            dict_item = {
                                "success": "true",
                                "msg": s
                            }
                            yield json.dumps(dict_item, ensure_ascii=False)
                        if stop_flag:
                            break
                    except json.JSONDecodeError as e:
                        print(f"JSON Parse Error: {e}")

                if stop_flag:
                    break
            except Exception as e:
                yield json.dumps({
                    "success": "false",
                    "msg": str(e)
                })
                break

    return EventSourceResponse(event_generator_json())


if __name__ == "__main__":
    pass



TYPE_BOT = "bot"
TYPE_USER = "user"
TYPE_SYSTEM = "system"

DATE_PATTERN = "%Y%m%d"
TIMEOUT_SECONDS = 30

VENDOR_OPENAI = "gpt"
VENDOR_MINIMAX = "minimax"
VENDOR_GOOGLE = "bard"
VENDOR_XUNFEI = "spark"
VENDOR_CLAUDE = "claude"
VENDOR_INTERNLM = "internlm"

DEFAULT_TIMEOUT_SECONDS = 600




import json

import requests
from sse_starlette.sse import EventSourceResponse

from openaoe.backend.config.biz_config import get_model_configuration, get_base_url
from openaoe.backend.config.constant import *
from openaoe.backend.model.minimax import MinimaxChatCompletionBody
from openaoe.backend.util.log import log

logger = log(__name__)


def get_req_param(request, req_dto):
    group_id = get_model_configuration(VENDOR_MINIMAX, "group_id")
    jwt = get_model_configuration(VENDOR_MINIMAX, "jwt")
    api_base = get_base_url(VENDOR_MINIMAX)
    headers = {
        "Authorization": jwt,
        "Content-Type": "application/json"
    }
    role_meta = {
        "user_name": req_dto.role_meta.user_name,
        "bot_name": req_dto.role_meta.bot_name
    }
    messages = [
        {"sender_type": msg.sender_type, "text": msg.text}
        for msg in req_dto.messages or []
    ]

    payload = {
        "model": req_dto.model,
        "prompt": req_dto.prompt,
        "role_meta": role_meta,
        "messages": messages,
        "stream": req_dto.stream,
        "tokens_to_generate": 4096
    }
    url = f'{api_base}/v1/text/chatcompletion?GroupId={group_id}'
    return url, headers, payload


def parse_chunk_delta(chunk):
    if not chunk:
        return "empty received"
    decoded_data = chunk.decode('utf-8')
    parsed_data = json.loads(decoded_data.replace("data:", ""))
    choices = parsed_data['choices']
    if choices is None:
        base_resp = parsed_data['base_resp']
        if base_resp is None:
            return parsed_data
        # sts_code = base_resp.get('status_code')
        sts_msg = base_resp.get('status_msg')
        return f"{sts_msg}"
    delta_content = choices[0]['delta']
    return delta_content


def should_stop(chunk) -> bool:
    if not chunk:
        return True
    decoded_data = chunk.decode('utf-8')
    # logger.info(f"decoded_data={decoded_data}")
    parsed_data = json.loads(decoded_data.replace("data:", ""))
    choices = parsed_data['choices']
    if choices is None:
        return True
    finish_reason = choices[0].get("finish_reason")
    # logger.info(f"finish_reason={finish_reason}")
    if finish_reason is None or finish_reason == "":
        return False
    return True


def minimax_chat_stream_svc(request, req_dto: MinimaxChatCompletionBody):
    async def event_generator():
        url, headers, payload = get_req_param(request, req_dto)

        while True:
            stop_flag = False
            if await request.is_disconnected():
                break
            try:
                response = requests.post(url=url, headers=headers, json=payload)
                for chunk in response.iter_lines():
                    if should_stop(chunk):
                        stop_flag = True
                        yield parse_chunk_delta(chunk)
                        break
                    if chunk:
                        yield parse_chunk_delta(chunk)
            except Exception as e:
                logger.error(f"{e}")
                stop_flag = True
                yield str(e)
            if stop_flag:
                break

    async def event_generator_json():
        url, headers, payload = get_req_param(request, req_dto)
        while True:
            stop_flag = False
            if await request.is_disconnected():
                logger.info("connection closed by request")
                break
            try:
                response = requests.post(url=url, headers=headers, json=payload)
                for chunk in response.iter_lines():
                    dict_item = {
                        "success": "true",
                        "msg": parse_chunk_delta(chunk)
                    }
                    yield json.dumps(dict_item, ensure_ascii=False)
                    if should_stop(chunk):
                        stop_flag = True
                        logger.info("connection closed by should_stop")
                        break
                if stop_flag:
                    break
            except Exception as e:
                logger.error(f"{e}")
                logger.info("connection closed by exception")
                dict_item = {
                    "success": "false",
                    "msg": str(e)
                }
                yield json.dumps(dict_item)
                break

    if req_dto.type == "text":
        return EventSourceResponse(event_generator())
    elif req_dto.type == "json":
        return EventSourceResponse(event_generator_json())





import argparse
import os

from fastapi import FastAPI
from fastapi.middleware.cors import CORSMiddleware
from fastapi.responses import FileResponse
from fastapi.staticfiles import StaticFiles
from starlette.responses import HTMLResponse

from openaoe.backend.api.route_claude import router as claude
from openaoe.backend.api.route_google import router as google
from openaoe.backend.api.route_internlm import router as internlm
from openaoe.backend.api.route_minimax import router as minimax
from openaoe.backend.api.route_openai import router as openai
from openaoe.backend.api.route_xunfei import router as xunfei
from openaoe.backend.config.biz_config import app_abs_path, img_out_path
from openaoe.backend.config.biz_config import load_config
from openaoe.backend.util.log import log
from openaoe.backend.util.str_util import safe_join

logger = log(__name__)

# define global variable
API_VER = 'v1'
base_dir = app_abs_path()
STATIC_RESOURCE_DIR = os.path.join(base_dir, "frontend/dist")
CSS_PATH_LIB = f"{STATIC_RESOURCE_DIR}/assets"
IMG_PATH_LIB = f"{STATIC_RESOURCE_DIR}/assets"
JS_PATH_LIB = f"{STATIC_RESOURCE_DIR}/js"
path = img_out_path()
OUT_IMG_PATH_LIB = f"{path}"

app = FastAPI()
app.mount("/static", StaticFiles(directory=STATIC_RESOURCE_DIR), name="static")


@app.get("/", response_class=HTMLResponse)
@app.get("/home", response_class=HTMLResponse)
async def server():
    return FileResponse(f"{STATIC_RESOURCE_DIR}/index.html")


@app.get("/assets/css/{path:path}")
async def build_resource(path: str):
    build_file = safe_join(CSS_PATH_LIB, path)
    return FileResponse(build_file)


@app.get("/{path:path}")
async def build_resource(path: str):
    static_file = safe_join(STATIC_RESOURCE_DIR, path)
    return FileResponse(static_file)


# add middlewares here if you need
app.add_middleware(
    CORSMiddleware,
    allow_origins=["*"],
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)

# add api routers
app.include_router(minimax, prefix=f"/{API_VER}/minimax")
app.include_router(openai, prefix=f"/{API_VER}/openai")
app.include_router(google, prefix=f"/{API_VER}/google")
app.include_router(claude, prefix=f"/{API_VER}/claude")
app.include_router(xunfei, prefix=f"/{API_VER}/xunfei")
app.include_router(internlm, prefix=f"/{API_VER}/internlm")


def main():
    parser = argparse.ArgumentParser(description="Example app using a YAML config file.")
    parser.add_argument('-f', '--file', type=str, required=True, help='Path to the YAML config file.')

    config_path = parser.parse_args()

    logger.info(f"your config file is: {config_path.file}")
    load_config(config_path.file)

    import uvicorn
    uvicorn.run(
        app,
        host='0.0.0.0',
        port=10099,
        timeout_keep_alive=600,
        workers=1
    )


if __name__ == "__main__":
    main()



from fastapi import APIRouter, Request

from openaoe.backend.model.minimax import MinimaxChatCompletionBody
from openaoe.backend.service.service_minimax import minimax_chat_stream_svc


router = APIRouter()


@router.post("/v1/text/chat-stream", tags=["MiniMax"])
async def minimax_chat_stream(request: Request, req_dto: MinimaxChatCompletionBody):
    req_dto.stream = True
    ret = minimax_chat_stream_svc(request, req_dto)
    return ret



from pydantic import BaseModel
from typing import Optional, List, Union, Dict
from openai._types import NOT_GIVEN


class Context(BaseModel):
    sender_type: str = "assistant"
    text: str = ''


class RoleMeta(BaseModel):
    user_name: Optional[str] = 'user'
    bot_name: Optional[str] = 'assistant'


class TextMsg(BaseModel):
    type: str = 'text'
    text: str


class ImgURL(BaseModel):
    url: str
    detail: Optional[str] = 'low'


class ImgMsg(BaseModel):
    type: str = 'image_url'
    image_url: ImgURL


class Message(BaseModel):
    role: str
    content: Optional[Union[str, List[Union[TextMsg, ImgMsg]]]] = ''


class InternlmChatCompletionBody(BaseModel):
    model: Optional[str] = 'internlm-chat-7b'
    role_meta: Optional[RoleMeta]
    prompt: Optional[str]
    messages: List[Context]
    temperature: Optional[float] = 0.7
    top_p: Optional[float] = 1
    n: Optional[int] = 1
    stop: Optional[Union[str, List]] = "false"
    presence_penalty: Optional[float] = 0
    frequency_penalty: Optional[float] = 0
    user: Optional[str] = NOT_GIVEN
    stream: Optional[bool] = False
    timeout: Optional[int] = 600
    session_id: Optional[int] = -1
    ignore_eos: Optional[bool] = False
    max_tokens: Optional[int] = 1024


class OpenaiChatCompletionV2Body(BaseModel):
    model: Optional[str] = 'gpt-3.5-turbo'
    messages: Union[str, List[Message]]
    temperature: Optional[float] = 1
    top_p: Optional[float] = 1
    n: Optional[int] = 1
    stream: Optional[bool] = False
    stop: Optional[Union[str, List]] = NOT_GIVEN
    max_tokens: Optional[int] = NOT_GIVEN
    presence_penalty: Optional[float] = NOT_GIVEN
    frequency_penalty: Optional[float] = NOT_GIVEN
    timeout: Optional[int] = 600


class OpenaiCompletionBody(BaseModel):
    """
        see https://platform.openai.com/docs/api-reference/completions/create
    """
    model: Optional[str] = 'text-davinci-003'
    prompt: Union[str, List]
    max_tokens: Optional[int] = 1024
    temperature: Optional[float] = 1
    top_p: Optional[float] = 1
    n: Optional[int] = 1
    echo: Optional[bool] = False
    stop: Optional[Union[str, List]] = NOT_GIVEN
    presence_penalty: Optional[float] = 0
    frequency_penalty: Optional[float] = 0
    best_of: Optional[int] = 1
    logit_bias: Optional[Dict] = NOT_GIVEN
    user: Optional[str] = NOT_GIVEN
    timeout: Optional[int] = 600


class OpenaiChatStreamBody(BaseModel):
    model: Optional[str] = 'gpt-3.5-turbo'
    prompt: str
    temperature: Optional[float] = 1
    messages: Optional[List[Context]] = None
    role_meta: Optional[RoleMeta] = None
    # return type: text or json
    type: Optional[str] = 'text'
    timeout: Optional[int] = 600
    # functions: Optional[List[Function]] = None
    # function_call: Optional[object] = 'auto'


class OpenaiCheckBody(BaseModel):
    model: Optional[str] = 'gpt-3.5-turbo'
    prompt: str
    api_key: str



import re
import time
import pytz
from datetime import datetime, timedelta
from time import mktime
from wsgiref.handlers import format_date_time

from openaoe.backend.util.log import logger
from openaoe.backend.config.constant import DATE_PATTERN


def get_current_date() -> str:
    cur_time = datetime.now()
    date = format_date_time(mktime(cur_time.timetuple()))
    return date


def get_current_datetime() -> datetime:
    tz = pytz.timezone('Asia/Shanghai')
    date = datetime.now(tz)
    return date


def get_human_friendly_date(date: datetime = None) -> str:
    if not date:
        date = get_current_datetime()
    return date.strftime(DATE_PATTERN)


def get_current_ts_ms() -> int:
    return int(round(time.time() * 1000))


def get_current_ts_s():
    return int(round(time.time()))


def parse_date(date: str, pattern: str):
    try:
        d = datetime.strptime(date, pattern)
        return d
    except ValueError as _:
        logger.error("invalid date: %s to format, pattern: %s", date, pattern)
        return None


def get_offset_date(offset_day: int, date: datetime=None) -> datetime:
    if not date:
        date = get_current_datetime()
    return date + timedelta(days=offset_day)


# [start_date, end_date)
def get_between_dates(start_date: datetime, end_date: datetime=None):
    if not end_date:
        end_date = get_current_datetime()

    if end_date <= start_date:
        return None

    ret = []
    while get_human_friendly_date(start_date) != get_human_friendly_date(end_date):
        ret.append(start_date)
        start_date = get_offset_date(1, start_date)
    return ret


def get_timestamp_after_openai_format_time(time_str):
    if not time_str:
        return None
    r = re.search("(\\d+)h(\\d+)m(\\d+)s", time_str)
    if r:
        hour = r.group(1)
        min = r.group(2)
        second = r.group(3)
        offset = 3600 * hour + 60 * min + second
        return get_current_ts_s() + offset
    return None





import sys
import yaml

from openaoe.backend.util.log import log
import os

logger = log(__name__)
biz_config = None


class BizConfig:
    def __init__(self, **args):
        self.__dict__.update(args)

    def get(self, field):
        if field in self.__dict__:
            return self.__dict__[field]
        return None


def load_config(config_path):
    logger.info(f"start to init configuration from {config_path}.")
    with open(config_path) as fin:
        m = yaml.safe_load(fin)
        if not m or len(m) == 0:
            logger.error("init configuration failed. Exit")
            sys.exit(-1)

        global biz_config
        biz_config = BizConfig(**m)
    logger.info("init configuration successfully.")


def get_configuration(field):
    if biz_config.get(field):
        return biz_config.get(field)
    return None


def get_model_configuration(vendor: str, field):
    models = get_configuration("models")
    if not models:
        logger.error(f"invalid configuration file")
        sys.exit(-1)

    if models.get(vendor) and models.get(vendor).get(field):
        conf = models.get(vendor).get(field)
        logger.info(f"biz_config={conf}")
        return conf

    logger.error(f"vendor: {vendor} has no field: {field} configuration")
    return ""


def get_base_url(vendor: str) -> str:
    return get_model_configuration(vendor, "api_base")


def get_api_key(vendor: str) -> str:
    return get_model_configuration(vendor, "api_key")


def app_abs_path():
    return os.path.dirname(os.path.abspath(__file__)).split("/backend")[0]


def img_out_path():
    abs_path = app_abs_path()
    return f'{abs_path}/frontend/dist/tmp/img/out'


def img_in_path():
    abs_path = app_abs_path()
    return f'{abs_path}/frontend/dist/tmp/img/in'



import json

from openai import OpenAI
from sse_starlette.sse import EventSourceResponse

from openaoe.backend.config.biz_config import get_api_key, get_base_url
from openaoe.backend.config.constant import *
from openaoe.backend.util.log import log

logger = log(__name__)


def messages_process(req_dto):
    prompt = req_dto.prompt
    contexts = req_dto.messages
    role_meta = req_dto.role_meta
    if role_meta is not None:
        user_name = role_meta.user_name
        bot_name = role_meta.bot_name
    else:
        user_name = "user"
        bot_name = "assistant"
    messages = [
                   {
                       "role": "user" if user_name == "user" else bot_name,
                       "content": context.text
                   }
                   for context in contexts or []
               ] + [
                   {
                       "role": "user",
                       "content": prompt
                   }]
    return messages


def chat_completion_stream(request, body):
    async def event_generator():
        while True:
            client = OpenAI(
                api_key=get_api_key(VENDOR_OPENAI),
                timeout=body.timeout,
                base_url=get_base_url(VENDOR_OPENAI)
            )

            stop_flag = False
            response = ""
            if await request.is_disconnected():
                break
            try:
                res = client.chat.completions.with_raw_response.create(
                    model=body.model,
                    messages=messages_process(body),
                    temperature=body.temperature,
                    stream=True,
                    timeout=body.timeout
                )

                for chunk in res.parse():
                    choice = chunk.choices[0]
                    s = choice.delta.content
                    if choice.finish_reason:
                        stop_flag = True
                    if s:
                        response += s
                        yield s
                    if stop_flag:
                        break
                if stop_flag:
                    break
            except Exception as e:
                yield str(e)
                break

    async def event_generator_json():
        while True:
            client = OpenAI(
                api_key=get_api_key(VENDOR_OPENAI),
                timeout=body.timeout,
                base_url=get_base_url(VENDOR_OPENAI)
            )
            stop_flag = False
            response = ""
            if await request.is_disconnected():
                break
            res = None
            try:
                res = client.chat.completions.with_raw_response.create(
                    model=body.model,
                    messages=messages_process(body),
                    temperature=body.temperature,
                    stream=True,
                    timeout=body.timeout
                )

                for chunk in res.parse():
                    choice = chunk.choices[0]
                    s = choice.delta.content
                    if choice.finish_reason:
                        stop_flag = True
                    if s:
                        response += s
                        dict_item = {
                            "success": "true",
                            "msg": s
                        }
                        yield json.dumps(dict_item, ensure_ascii=False)
                    if stop_flag:
                        break
                if stop_flag:
                    break
            except Exception as e:
                yield json.dumps({
                    "success": "false",
                    "msg": str(e)
                })
                break

    if body.type == 'text':
        return EventSourceResponse(event_generator())
    elif body.type == 'json':
        return EventSourceResponse(event_generator_json())


if __name__ == "__main__":
    pass



#!/usr/bin/env python
# Copyright (c) didigo. All rights reserved.
from setuptools import find_packages, setup
import openaoe.backend.util.file as utils
import os

def recursive_files(base_dir):
    file_list = []
    for dirpath, dirnames, filenames in os.walk(base_dir):
        for filename in filenames:
            file_list.append(os.path.join(dirpath, filename))
    return file_list

setup(
    name='openaoe',
    version='0.0.1',
    description='LLM Group Chat Framework: chat with multiple LLMs at the same time',
    long_description=utils.get_file_content("README.md"),
    long_description_content_type='text/markdown',
    author='arkmon',
    author_email='',
    keywords=['openaoe','open-aoe'],
    url='https://github.com/internlm/openaoe',
    packages=find_packages(),
    include_package_data=True,
    package_data={
        'openaoe': ['frontend/dist/*', 'frontend/dist/**/*']
    },
    zip_safe=False,
    classifiers=[
        'Development Status :: 3 - Alpha',
    ],
    license='Apache License 2.0',
    install_requires=utils.parse_requirements('openaoe/backend/requirements.txt'),
    entry_points={
        'console_scripts': [
              'openaoe=openaoe.main:main'
        ]
    },
    ext_modules=[],

)



from pydantic import BaseModel
from typing import Optional


class AOEResponse(BaseModel):
    msg: Optional[str] = "ok"
    msgCode: Optional[str] = "10000"
    data: Optional[object] = None


class AOEProxyResponse(BaseModel):
    statusCode: Optional[int] = 200
    headers: Optional[dict] = {}
    body: Optional[object] = None
    msg: Optional[str] = 'ok'
    data: Optional[dict] = {}




from pydantic import BaseModel
from typing import Optional, List, Union


class RoleMeta(BaseModel):
    user_name: str
    bot_name: str


class Messages(BaseModel):
    sender_type: str
    text: str


class MinimaxChatCompletionBody(BaseModel):
    model: Optional[str] = 'abab5-chat'
    prompt: str
    role_meta: Optional[Union[RoleMeta, None]] = None
    messages: Optional[List[Messages]] = None
    stream: Optional[bool] = False
    type: Optional[str] = "text"

